# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/derivatives_instrument_metrics_v1/request.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from kaikosdk.core import instrument_criteria_pb2 as sdk_dot_core_dot_instrument__criteria__pb2
from kaikosdk.stream.derivatives_instrument_metrics_v1 import commodity_kind_pb2 as sdk_dot_stream_dot_derivatives__instrument__metrics__v1_dot_commodity__kind__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n:sdk/stream/derivatives_instrument_metrics_v1/request.proto\x12\x08kaikosdk\x1a\"sdk/core/instrument_criteria.proto\x1a\x41sdk/stream/derivatives_instrument_metrics_v1/commodity_kind.proto\"\xb3\x01\n+StreamDerivativesInstrumentMetricsRequestV1\x12\x39\n\x13instrument_criteria\x18\x01 \x01(\x0b\x32\x1c.kaikosdk.InstrumentCriteria\x12I\n\x0b\x63ommodities\x18\x02 \x03(\x0e\x32\x34.kaikosdk.StreamDerivativesInstrumentCommodityKindV1B\xd9\x01\n6com.kaiko.sdk.stream.derivatives_instrument_metrics_v1P\x01Zlgithub.com/kaikodata/kaiko-go-sdk/stream/derivatives_instrument_metrics_v1;derivatives_instrument_metrics_v1\xaa\x02.KaikoSdk.Stream.DerivativesInstrumentMetricsV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.derivatives_instrument_metrics_v1.request_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n6com.kaiko.sdk.stream.derivatives_instrument_metrics_v1P\001Zlgithub.com/kaikodata/kaiko-go-sdk/stream/derivatives_instrument_metrics_v1;derivatives_instrument_metrics_v1\252\002.KaikoSdk.Stream.DerivativesInstrumentMetricsV1'
  _globals['_STREAMDERIVATIVESINSTRUMENTMETRICSREQUESTV1']._serialized_start=176
  _globals['_STREAMDERIVATIVESINSTRUMENTMETRICSREQUESTV1']._serialized_end=355
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: sdk/stream/composite_indices_v1/response.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from kaikosdk.stream.index_v1 import commodity_pb2 as sdk_dot_stream_dot_index__v1_dot_commodity__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.sdk/stream/composite_indices_v1/response.proto\x12\x08kaikosdk\x1a\x1fgoogle/protobuf/timestamp.proto\x1a#sdk/stream/index_v1/commodity.proto\"\xa3\x01\n0StreamCompositeIndicesServiceResponseComposition\x12\x11\n\trate_code\x18\x01 \x01(\t\x12\x12\n\x05price\x18\x02 \x01(\x01H\x00\x88\x01\x01\x12\x13\n\x06weight\x18\x03 \x01(\x01H\x01\x88\x01\x01\x12\x13\n\x06volume\x18\x04 \x01(\x01H\x02\x88\x01\x01\x42\x08\n\x06_priceB\t\n\x07_weightB\t\n\x07_volume\"\x91\x01\n)StreamCompositeIndicesServiceResponseData\x12\r\n\x05price\x18\x01 \x01(\x01\x12U\n\x11\x63omposition_rates\x18\x02 \x03(\x0b\x32:.kaikosdk.StreamCompositeIndicesServiceResponseComposition\"\xbf\x02\n\'StreamCompositeIndicesServiceResponseV1\x12\x31\n\tcommodity\x18\x01 \x01(\x0e\x32\x1e.kaikosdk.StreamIndexCommodity\x12\x12\n\nindex_code\x18\x02 \x01(\t\x12\x41\n\x04\x64\x61ta\x18\x03 \x01(\x0b\x32\x33.kaikosdk.StreamCompositeIndicesServiceResponseData\x12.\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12,\n\x08ts_event\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampB\xa6\x01\n)com.kaiko.sdk.stream.composite_indices_v1P\x01ZRgithub.com/kaikodata/kaiko-go-sdk/stream/composite_indices_v1;composite_indices_v1\xaa\x02\"KaikoSdk.Stream.CompositeIndicesV1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'sdk.stream.composite_indices_v1.response_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:
  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n)com.kaiko.sdk.stream.composite_indices_v1P\001ZRgithub.com/kaikodata/kaiko-go-sdk/stream/composite_indices_v1;composite_indices_v1\252\002\"KaikoSdk.Stream.CompositeIndicesV1'
  _globals['_STREAMCOMPOSITEINDICESSERVICERESPONSECOMPOSITION']._serialized_start=131
  _globals['_STREAMCOMPOSITEINDICESSERVICERESPONSECOMPOSITION']._serialized_end=294
  _globals['_STREAMCOMPOSITEINDICESSERVICERESPONSEDATA']._serialized_start=297
  _globals['_STREAMCOMPOSITEINDICESSERVICERESPONSEDATA']._serialized_end=442
  _globals['_STREAMCOMPOSITEINDICESSERVICERESPONSEV1']._serialized_start=445
  _globals['_STREAMCOMPOSITEINDICESSERVICERESPONSEV1']._serialized_end=764
# @@protoc_insertion_point(module_scope)
